library zhihu_daily.extractor;

import 'model.dart';

/// 从http body中抽取启动界面图像
StartImage extractStartImage(Map body) {
  var result;
  if (body.containsKey('text') && body.containsKey('img')) {
    result = new StartImage.fromJson(body);
  }
  return result;
}

/// 从http body中抽取最新消息
List<List<News>> extractLatestNews(Map body) {
  var result = <List<News>>[];
  if (body.containsKey('date') && body.containsKey('stories')) {
    String date = body['date'];
    List list = body['top_stories'];
    List<News> topStories = <News>[];
    for (var item in list) {
      topStories.add(new News.fromJson(item, top: true)..date = date);
    }
    result.add(topStories);

    list = body['stories'];
    List<News> stories = <News>[];
    for (var item in list) {
      stories.add(new News.fromJson(item)..date = date);
    }
    result.add(stories);
  }
  return result;
}

/// 从http body中抽取消息内容
Story extractStory(Map body) {
  var result;
  if (body.containsKey('body') && body.containsKey('id')) {
    result = new Story.fromJson(body);
  }
  return result;
}

/// 从http body中抽取过往消息
List<News> extractOldNews(Map body) {
  var result = <News>[];
  if (body.containsKey('date') && body.containsKey('stories')) {
    String newsDate = body['date'];
    List list = body['stories'];
    for (var item in list) {
      result.add(new News.fromJson(item, top: true)..date = newsDate);
    }
  }
  return result;
}

/// 从http body中抽取消息额外信息
StoryExtra extractStoryExtra(Map body, int storyId) {
  var result;
  if (body.containsKey('popularity') && body.containsKey('comments')) {
    result = new StoryExtra.fromJson(body)..storyId = storyId;
  }
  return result;
}

/// 从http body中抽取长评论
List<Comment> extractLongComments(Map body) {
  var result = <Comment>[];
  if (body.containsKey('comments')) {
    List list = body['comments'];
    for (var item in list) {
      result.add(new Comment.fromJson(item)..isLong = true);
    }
  }
  return result;
}

/// 从http body中抽取短评论
List<Comment> extractShortComments(Map body) {
  var result = <Comment>[];
  if (body.containsKey('comments')) {
    List list = body['comments'];
    for (var item in list) {
      result.add(new Comment.fromJson(item)..isShort = true);
    }
  }
  return result;
}

/// 从http body中抽取主题日报列表
List<Theme> extractThemes(Map body) {
  var result = <Theme>[];
  if (body.containsKey('others') || body.containsKey('subscribed')) {
    List list = body['others'];
    List list2 = body['subscribed'];
    list.addAll(list2);
    for (var item in list) {
      result.add(new Theme.fromJson(item));
    }
  }
  return result;
}

/// 从http body中抽取主题日报内容
ThemeContent extractThemeContent(Map body) {
  var result;
  if (body.containsKey('name') && body.containsKey('stories')) {
    result = new ThemeContent.fromJson(body);
  }
  return result;
}
