/// 非官方知乎日报 Dart SDK，所有API信息都取自非官方的[知乎日报API分析](https://github.com/izzyleung/ZhihuDailyPurify/wiki/%E7%9F%A5%E4%B9%8E%E6%97%A5%E6%8A%A5-API-%E5%88%86%E6%9E%90)。
library zhihu_daily;

import 'dart:convert';
import 'dart:async';

import 'package:http/http.dart';

import 'src/constant.dart';
import 'src/model.dart';
import 'src/util.dart';
import 'src/interface.dart';
import 'src/extractor.dart';

export 'src/model.dart';

/// 知乎日报Api默认实现类
class ZhihuDaily implements ZhihuDailyApi {
  /// 获取启动界面图像
  Future<StartImage> fetchStartImage(
      {StartImageSize size: StartImageSize.size720}) async {
    var response =
        await get(buildUrl(ApiType.startImage, startImageSize: size));
    Map body = JSON.decode(response.body);
    return extractStartImage(body);
  }

  /// 获取最新消息
  ///
  /// 返回结果中的第一个列表为头条，第二个列表是普通消息
  Future<List<List<News>>> fetchLatestNews() async {
    var response = await get(buildUrl(ApiType.latestNews));
    Map body = JSON.decode(response.body);
    return extractLatestNews(body);
  }

  /// 获取消息内容
  Future<Story> fetchStory(int storyId) async {
    var response = await get(buildUrl(ApiType.story, storyId: storyId));
    Map body = JSON.decode(response.body);
    return extractStory(body);
  }

  /// 获取过往消息
  Future<List<News>> fetchOldNews({String date}) async {
    var response = await get(buildUrl(ApiType.oldNews, beforeDate: date));
    Map body = JSON.decode(response.body);
    return extractOldNews(body);
  }

  /// 获取消息额外信息
  Future<StoryExtra> fetchStoryExtra(int storyId) async {
    var response = await get(buildUrl(ApiType.storyExtra, storyId: storyId));
    Map body = JSON.decode(response.body);
    return extractStoryExtra(body, storyId);
  }

  /// 获取长评论
  Future<List<Comment>> fetchLongComments(int storyId) async {
    var response = await get(buildUrl(ApiType.longComments, storyId: storyId));
    Map body = JSON.decode(response.body);
    return extractLongComments(body);
  }

  /// 获取短评论
  Future<List<Comment>> fetchShortComments(int storyId) async {
    var response = await get(buildUrl(ApiType.shortComments, storyId: storyId));
    Map body = JSON.decode(response.body);
    return extractShortComments(body);
  }

  /// 获取主题日报列表
  Future<List<Theme>> fetchThemes() async {
    var response = await get(buildUrl(ApiType.themes));
    Map body = JSON.decode(response.body);
    return extractThemes(body);
  }

  /// 获取主题日报内容
  Future<ThemeContent> fetchThemeContent(int themeId) async {
    var response = await get(buildUrl(ApiType.themeContent, themeId: themeId));
    Map body = JSON.decode(response.body);
    return extractThemeContent(body);
  }
}
